@@ -52,7 +52,7 @@ class Mouse(InfoBaseClass):
     @property
     def project(self) -> str | None:
         "Project associated with the mouse."
-        return self.lims.get("project")
+        return self.lims.get("project_name")
     
     @cached_property
     def state(self) -> State:
